@@ -13,7 +13,7 @@ use Scalar::Util 'weaken';
 use POSIX ':errno_h';
 
 # ABSTRACT: Template Toolkit renderer for Mojolicious
-our $VERSION = '1.49'; # VERSION
+our $VERSION = '1.51'; # VERSION
 
 __PACKAGE__->attr('tt');
 
@@ -226,13 +226,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Mojolicious::Plugin::TtRenderer::Engine - Template Toolkit renderer for Mojolicious
 
 =head1 VERSION
 
-version 1.49
+version 1.51
 
 =head1 SYNOPSIS
 
@@ -262,7 +264,19 @@ Add the handler:
 
 Template parameter are taken from C<$c-E<gt>stash>.
 
-=encoding utf-8
+=head1 DESCRIPTION
+
+See L<Mojolicious::Plugin::TtRenderer> for details on the plugin interface to this module.
+
+This module provides an engine for the rendering of L<Template Toolkit|Template> templates
+within a Mojolicious context.  Templates may be, stored on the local file system, provided
+inline by the controller or included in the C<__DATA__> section.  Where possible this modules
+attempts to provide a TT analogue interface to the L<Perlish templates|Mojo::Template> which 
+come with Mojolicious.
+
+=for stopwords Bjørn
+Szász
+Árpád
 
 =head1 RENDERING
 
@@ -304,7 +318,7 @@ object. When used the INCLUDE_PATH will be set to
 A hash reference of options that are passed to Template->new().  Note that if you
 specify an C<INCLUDE_PATH> through this option it will remove the DATA section
 templates from your path.  A better way to specify an C<INCLUDE_PATH> if you also
-want to use DATA section templates it by manipulting the L<Mojolicious::Renderer>
+want to use DATA section templates it by manipulating the L<Mojolicious::Renderer>
 path.
 
 =item cache_dir
@@ -316,7 +330,7 @@ templates. Will default to a temp-dir if not set.
 
 =head1 SEE ALSO
 
-L<Mojolicious::Plugin::TtRenderer::Engine>, 
+L<Mojolicious::Plugin::TtRenderer>, 
 L<Mojolicious>, 
 L<Mojolicious::Guides>, 
 L<http://mojolicious.org>.
@@ -357,9 +371,13 @@ spleenjack
 
 Árpád Szász
 
+Сергей Романов
+
+uwisser
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ask Bjørn Hansen.
+This software is copyright (c) 2014 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
